@@ -227,6 +227,16 @@ class ObjectStorageContextFileMixin(metaclass=ABCMeta):
         """
         raise NotImplementedError()
 
+    @abstractmethod
+    def downloadLargeFiles(self):
+        """Ensure Large Files
+
+        Downloads all missing large files that have a remoteUri set
+
+        :return: None
+        """
+        raise NotImplementedError()
+
 
 class ObjectStorageContext(ObjectStorageContextFileMixin):
     _ItemParentClassByTupleType: dict[str, type[StorageTuple]] = {}
