@@ -9,6 +9,9 @@ from typing import Optional
 
 import pygit2
 import pytz
+from twisted.internet.defer import DeferredList
+from twisted.internet.defer import DeferredSemaphore
+from twisted.internet.defer import inlineCallbacks
 from vortex.Tuple import Tuple
 
 from .git_lib_mixin import GitLibMixin
@@ -20,7 +23,11 @@ from ..ObjectStorageContext import VersionedFileContent
 from ..ObjectStorageContext import VersionedFileInfo
 from ..StorageTuple import ItemStorageGroupEnum
 from ..StorageTuple import StorageTuple
+from .._private.large_file_http_downloader import LargeFileHttpDownloader
 from .._private.utils import makeStorageKey
+from ..items.file_archive_tuples.file_tuple_constants import (
+    FileArchiveTupleTypeEnum,
+)
 
 
 logger = logging.getLogger(__name__)
@@ -163,7 +170,7 @@ class GitObjectStorageContextFileMixin(ObjectStorageContextFileMixin):
         )
 
         self._writeFile(
-            str(treePath),
+            treePath.as_posix(),
             data,
             mode=mode,
         )
@@ -214,6 +221,40 @@ class GitObjectStorageContextFileMixin(ObjectStorageContextFileMixin):
         path.mkdir(mode=DIR_CREATE_MODE, parents=True, exist_ok=True)
         return path
 
+    @inlineCallbacks
+    def downloadLargeFiles(self):
+        semophore = DeferredSemaphore(4)
+        deferreds = []
+        archivesToBeDownloaded = []
+        for item in self.getItems(ItemStorageGroupEnum.FileArchive):
+            if item.tupleType() != FileArchiveTupleTypeEnum.LARGE.value:
+                continue
+
+            path = item.archivePath
+            # A large file is already present
+            if path.exists():
+                continue
+
+            # Download only if item has URI to download file from
+            if not item.remoteUri:
+                continue
+
+            archivesToBeDownloaded.append(item)
+            downloader = LargeFileHttpDownloader(
+                item.remoteUri, item.archivePath
+            )
+            deferreds.append(semophore.run(downloader.download))
+
+        deferredsResult = yield DeferredList(deferreds)
+        for archive, (success, resultOrFailures) in zip(
+            archivesToBeDownloaded, deferredsResult
+        ):
+            if success:
+                logger.info(f"Downloaded large file for {archive.key}")
+            else:
+                logger.info(f"Failed to download file for {archive.key}")
+            # TODO, Check result?
+
 
 class GitObjectStorageContext(
     GitLibMixin, ObjectStorageContext, GitObjectStorageContextFileMixin
@@ -432,7 +473,7 @@ class GitObjectStorageContext(
         itemPath = Path(f"{group}/{sanitizedItemKey}")
 
         self._writeFile(
-            str(itemPath / "metadata.json"),
+            (itemPath / "metadata.json").as_posix(),
             json.dumps(
                 fields,
                 indent=4,
@@ -442,9 +483,9 @@ class GitObjectStorageContext(
         )
 
         if comment:
-            self._writeFile(str(itemPath / "comment.md"), comment.encode())
+            self._writeFile((itemPath / "comment.md").as_posix(), comment.encode())
         if script:
-            self._writeFile(str(itemPath / "script.txt"), script.encode())
+            self._writeFile((itemPath / "script.txt").as_posix(), script.encode())
 
     def __moveItemDirectory(
         self, group: ItemStorageGroupEnum, oldKey: str, newKey: str
